#
# spec file for package python-bloscpack
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-bloscpack
Version:        0.16.0
Release:        7.8
Summary:        Command line interface and serialization format for Blosc
License:        MIT
URL:            https://github.com/blosc/bloscpack
Source:         https://files.pythonhosted.org/packages/source/b/bloscpack/bloscpack-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM remove_nose.patch gh#Blosc/bloscpack#99 mcepl@suse.com
# Remove nose dependency
Patch0:         remove_nose.patch
# PATCH-FIX-UPSTREAM drop-python2-support.patch gh#Blosc/bloscpack#118
Patch1:         drop-python2-support.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-blosc
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     cryptography >= 1.3.4
Recommends:     python-pyOpenSSL >= 0.14
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module blosc}
BuildRequires:  %{python_module cryptography >= 1.3.4}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pyOpenSSL >= 0.14}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Command line interface and serialization format for Blosc, a
multi-threaded, blocking and shuffling compressor. It uses
python-blosc bindings to interface with Blosc. It also comes with native
support for serializing and deserializing Numpy arrays.

%prep
%autosetup -p1 -n bloscpack-%{version}

find bloscpack -name '*.py' -exec sed -i '1{\@^#!%{_bindir}/env python@d}' {} +

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_clone -a %{buildroot}%{_bindir}/blpk
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%python_exec -c 'import blosc'
# Tests are completely broken (gh#Blosc/bloscpack#99)
# %%pytest

%post
%python_install_alternative blpk

%postun
%python_uninstall_alternative blpk

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/blpk
%{python_sitelib}/bloscpack
%{python_sitelib}/bloscpack-%{version}*-info

%changelog
* Thu Nov  3 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-python2-support.patch to remove python-six
  gh#Blosc/bloscpack#118
- Remove python_module definition
* Sun Jan 16 2022 Benjamin Greiner <code@bnavigator.de>
- Remove unused coverage packages from dependencies
- Skip python2 builds, remove mock dependency.
  * (unused, not testing due to still no release despite
    gh#Blosc/bloscpack#103)
* Wed Apr 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Thu Aug  6 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove dependency on nose
  (https://github.com/Blosc/bloscpack/issues/99).
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 22 2020 Steve Kowalik <steven.kowalik@suse.com>
- Fix build without python2
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.16.0
  * The Python API naming has been overhauled and a few functions have been
    deprecated. Also the documentation for the Python API has been extended
    to inlcude more uses cases and potential applications.
* Fri Nov 23 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and odd grammar from descriptions.
* Tue Nov 13 2018 Todd R <toddrme2178@gmail.com>
- Initial version
